All of lore.kernel.org
 help / color / mirror / Atom feed
* [PATCH 0/5] Change old mail addresses to current ones
@ 2012-05-16  9:41 Oskar Schirmer
  2012-05-16  9:41 ` [PATCH 1/5] xtensa: Change mail addresses of Hannes Weiner and Oskar Oskar Schirmer
                   ` (4 more replies)
  0 siblings, 5 replies; 13+ messages in thread
From: Oskar Schirmer @ 2012-05-16  9:41 UTC (permalink / raw)
  To: linux-kernel; +Cc: trivial, hannes, shess, Oskar Schirmer

Several old mail addresses are no longer functional, e.g.:

SMTP error from remote mail server after RCPT TO:<os@emlix.com>:
host 192.168.3.31 [192.168.3.31]: 550 Unknown user

To avoid confusion change to some authors' current addresses.

Oskar Schirmer (5):
  xtensa: Change mail addresses of Hannes Weiner and Oskar Schirmer
  i2c: Change mail address of Oskar Schirmer
  net: Change mail address of Oskar Schirmer
  lib: Change mail address of Oskar Schirmer
  arm/m68k: Change mail address of Sebastian Heß

 arch/m68k/platform/532x/config.c                  |    2 +-
 arch/xtensa/variants/s6000/dmac.c                 |    2 +-
 arch/xtensa/variants/s6000/gpio.c                 |    4 ++--
 arch/xtensa/variants/s6000/include/variant/dmac.h |    2 +-
 arch/xtensa/variants/s6000/irq.c                  |    4 ++--
 drivers/i2c/busses/i2c-s6000.c                    |    2 +-
 drivers/i2c/busses/i2c-s6000.h                    |    2 +-
 drivers/net/ethernet/s6gmac.c                     |    4 ++--
 include/linux/rational.h                          |    2 +-
 lib/rational.c                                    |    2 +-
 10 files changed, 13 insertions(+), 13 deletions(-)

-- 
1.7.5.4


^ permalink raw reply	[flat|nested] 13+ messages in thread

* [PATCH 1/5] xtensa: Change mail addresses of Hannes Weiner and Oskar
  2012-05-16  9:41 [PATCH 0/5] Change old mail addresses to current ones Oskar Schirmer
@ 2012-05-16  9:41 ` Oskar Schirmer
  2012-05-17 13:15   ` Jiri Kosina
  2012-05-16  9:41 ` [PATCH 2/5] i2c: Change mail address of Oskar Schirmer Oskar Schirmer
                   ` (3 subsequent siblings)
  4 siblings, 1 reply; 13+ messages in thread
From: Oskar Schirmer @ 2012-05-16  9:41 UTC (permalink / raw)
  To: linux-kernel; +Cc: trivial, hannes, shess, Oskar Schirmer, Chris Zankel

These old mail addresses dont exist any more.
This changes all occurences to the authors' current addresses.

Signed-off-by: Oskar Schirmer <oskar@scara.com>
Cc: Hannes Weiner <hannes@cmpxchg.org>
Cc: Chris Zankel <chris@zankel.net>
---
 arch/xtensa/variants/s6000/dmac.c                 |    2 +-
 arch/xtensa/variants/s6000/gpio.c                 |    4 ++--
 arch/xtensa/variants/s6000/include/variant/dmac.h |    2 +-
 arch/xtensa/variants/s6000/irq.c                  |    4 ++--
 4 files changed, 6 insertions(+), 6 deletions(-)

diff --git a/arch/xtensa/variants/s6000/dmac.c b/arch/xtensa/variants/s6000/dmac.c
index dc7f7c5..340f5bb 100644
--- a/arch/xtensa/variants/s6000/dmac.c
+++ b/arch/xtensa/variants/s6000/dmac.c
@@ -1,5 +1,5 @@
 /*
- * Authors:	Oskar Schirmer <os@emlix.com>
+ * Authors:	Oskar Schirmer <oskar@scara.com>
  *		Daniel Gloeckner <dg@emlix.com>
  * (c) 2008 emlix GmbH http://www.emlix.com
  *
diff --git a/arch/xtensa/variants/s6000/gpio.c b/arch/xtensa/variants/s6000/gpio.c
index 7af0757..b89541b 100644
--- a/arch/xtensa/variants/s6000/gpio.c
+++ b/arch/xtensa/variants/s6000/gpio.c
@@ -2,8 +2,8 @@
  * s6000 gpio driver
  *
  * Copyright (c) 2009 emlix GmbH
- * Authors:	Oskar Schirmer <os@emlix.com>
- *		Johannes Weiner <jw@emlix.com>
+ * Authors:	Oskar Schirmer <oskar@scara.com>
+ *		Johannes Weiner <hannes@cmpxchg.org>
  *		Daniel Gloeckner <dg@emlix.com>
  */
 #include <linux/bitops.h>
diff --git a/arch/xtensa/variants/s6000/include/variant/dmac.h b/arch/xtensa/variants/s6000/include/variant/dmac.h
index e81735b..3f88d9f 100644
--- a/arch/xtensa/variants/s6000/include/variant/dmac.h
+++ b/arch/xtensa/variants/s6000/include/variant/dmac.h
@@ -8,7 +8,7 @@
  * Copyright (C) 2006 Tensilica Inc.
  * Copyright (C) 2008 Emlix GmbH <info@emlix.com>
  * Authors:	Fabian Godehardt <fg@emlix.com>
- *		Oskar Schirmer <os@emlix.com>
+ *		Oskar Schirmer <oskar@scara.com>
  *		Daniel Gloeckner <dg@emlix.com>
  */
 
diff --git a/arch/xtensa/variants/s6000/irq.c b/arch/xtensa/variants/s6000/irq.c
index 6651e32..81a241e 100644
--- a/arch/xtensa/variants/s6000/irq.c
+++ b/arch/xtensa/variants/s6000/irq.c
@@ -2,8 +2,8 @@
  * s6000 irq crossbar
  *
  * Copyright (c) 2009 emlix GmbH
- * Authors:	Johannes Weiner <jw@emlix.com>
- *		Oskar Schirmer <os@emlix.com>
+ * Authors:	Johannes Weiner <hannes@cmpxchg.org>
+ *		Oskar Schirmer <oskar@scara.com>
  */
 #include <linux/io.h>
 #include <asm/irq.h>
-- 
1.7.5.4


^ permalink raw reply related	[flat|nested] 13+ messages in thread

* [PATCH 2/5] i2c: Change mail address of Oskar Schirmer
  2012-05-16  9:41 [PATCH 0/5] Change old mail addresses to current ones Oskar Schirmer
  2012-05-16  9:41 ` [PATCH 1/5] xtensa: Change mail addresses of Hannes Weiner and Oskar Oskar Schirmer
@ 2012-05-16  9:41 ` Oskar Schirmer
  2012-05-24  9:18   ` Sonic Zhang
  2012-05-16  9:41 ` [PATCH 3/5] net: " Oskar Schirmer
                   ` (2 subsequent siblings)
  4 siblings, 1 reply; 13+ messages in thread
From: Oskar Schirmer @ 2012-05-16  9:41 UTC (permalink / raw)
  To: linux-kernel; +Cc: trivial, hannes, shess, Oskar Schirmer, Jean Delvare

That old mail address doesnt exist any more.
This changes all occurences to my new address.

Signed-off-by: Oskar Schirmer <oskar@scara.com>
Cc: Jean Delvare <khali@linux-fr.org>
---
 drivers/i2c/busses/i2c-s6000.c |    2 +-
 drivers/i2c/busses/i2c-s6000.h |    2 +-
 2 files changed, 2 insertions(+), 2 deletions(-)

diff --git a/drivers/i2c/busses/i2c-s6000.c b/drivers/i2c/busses/i2c-s6000.c
index c64ba73..b76a29d 100644
--- a/drivers/i2c/busses/i2c-s6000.c
+++ b/drivers/i2c/busses/i2c-s6000.c
@@ -3,7 +3,7 @@
  *
  * Description: Driver for S6000 Family I2C Interface
  * Copyright (c) 2008 emlix GmbH
- * Author:	Oskar Schirmer <os@emlix.com>
+ * Author:	Oskar Schirmer <oskar@scara.com>
  *
  * Partially based on i2c-bfin-twi.c driver by <sonic.zhang@analog.com>
  * Copyright (c) 2005-2007 Analog Devices, Inc.
diff --git a/drivers/i2c/busses/i2c-s6000.h b/drivers/i2c/busses/i2c-s6000.h
index ff23b81..4936f9f 100644
--- a/drivers/i2c/busses/i2c-s6000.h
+++ b/drivers/i2c/busses/i2c-s6000.h
@@ -6,7 +6,7 @@
  * for more details.
  *
  * Copyright (C) 2008 Emlix GmbH <info@emlix.com>
- * Author:	Oskar Schirmer <os@emlix.com>
+ * Author:	Oskar Schirmer <oskar@scara.com>
  */
 
 #ifndef __DRIVERS_I2C_BUSSES_I2C_S6000_H
-- 
1.7.5.4


^ permalink raw reply related	[flat|nested] 13+ messages in thread

* [PATCH 4/5] lib: Change mail address of Oskar Schirmer
  2012-05-16  9:41 [PATCH 0/5] Change old mail addresses to current ones Oskar Schirmer
                   ` (2 preceding siblings ...)
  2012-05-16  9:41 ` [PATCH 3/5] net: " Oskar Schirmer
@ 2012-05-16  9:41 ` Oskar Schirmer
  2012-05-17 13:18   ` Jiri Kosina
  2012-05-16  9:41 ` [PATCH 5/5] arm/m68k: Change mail address of Se Oskar Schirmer
  4 siblings, 1 reply; 13+ messages in thread
From: Oskar Schirmer @ 2012-05-16  9:41 UTC (permalink / raw)
  To: linux-kernel; +Cc: trivial, hannes, shess, Oskar Schirmer, Paul Gortmaker

That old mail address doesnt exist any more.
This changes all occurences to my new address.

Signed-off-by: Oskar Schirmer <oskar@scara.com>
Cc: Paul Gortmaker <paul.gortmaker@windriver.com>
---
 include/linux/rational.h |    2 +-
 lib/rational.c           |    2 +-
 2 files changed, 2 insertions(+), 2 deletions(-)

diff --git a/include/linux/rational.h b/include/linux/rational.h
index 4f532fc..bfa6a2b 100644
--- a/include/linux/rational.h
+++ b/include/linux/rational.h
@@ -1,7 +1,7 @@
 /*
  * rational fractions
  *
- * Copyright (C) 2009 emlix GmbH, Oskar Schirmer <os@emlix.com>
+ * Copyright (C) 2009 emlix GmbH, Oskar Schirmer <oskar@scara.com>
  *
  * helper functions when coping with rational numbers,
  * e.g. when calculating optimum numerator/denominator pairs for
diff --git a/lib/rational.c b/lib/rational.c
index d326da3..f0aa21c 100644
--- a/lib/rational.c
+++ b/lib/rational.c
@@ -1,7 +1,7 @@
 /*
  * rational fractions
  *
- * Copyright (C) 2009 emlix GmbH, Oskar Schirmer <os@emlix.com>
+ * Copyright (C) 2009 emlix GmbH, Oskar Schirmer <oskar@scara.com>
  *
  * helper functions when coping with rational numbers
  */
-- 
1.7.5.4


^ permalink raw reply related	[flat|nested] 13+ messages in thread

* [PATCH 5/5] arm/m68k: Change mail address of Se
  2012-05-16  9:41 [PATCH 0/5] Change old mail addresses to current ones Oskar Schirmer
                   ` (3 preceding siblings ...)
  2012-05-16  9:41 ` [PATCH 4/5] lib: " Oskar Schirmer
@ 2012-05-16  9:41 ` Oskar Schirmer
  2012-05-17 13:17   ` Jiri Kosina
  4 siblings, 1 reply; 13+ messages in thread
From: Oskar Schirmer @ 2012-05-16  9:41 UTC (permalink / raw)
  To: linux-kernel; +Cc: trivial, hannes, shess, Oskar Schirmer, Geert Uytterhoeven

That old mail address doesnt exist any more.
This changes all occurences to a current address.

Signed-off-by: Oskar Schirmer <oskar@scara.com>
Acked-by: Sebastian Heß <shess@hessware.de>
Cc: Geert Uytterhoeven <geert@linux-m68k.org>
---
 arch/m68k/platform/532x/config.c |    2 +-
 1 files changed, 1 insertions(+), 1 deletions(-)

diff --git a/arch/m68k/platform/532x/config.c b/arch/m68k/platform/532x/config.c
index 37082d0..21d6cb1 100644
--- a/arch/m68k/platform/532x/config.c
+++ b/arch/m68k/platform/532x/config.c
@@ -7,7 +7,7 @@
  *	Copyright (C) 2000, Lineo (www.lineo.com)
  *	Yaroslav Vinogradov yaroslav.vinogradov@freescale.com
  *	Copyright Freescale Semiconductor, Inc 2006
- *	Copyright (c) 2006, emlix, Sebastian Hess <sh@emlix.com>
+ *	Copyright (c) 2006, emlix, Sebastian Hess <shess@hessware.de>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
-- 
1.7.5.4


^ permalink raw reply related	[flat|nested] 13+ messages in thread

* [PATCH 3/5] net: Change mail address of Oskar Schirmer
  2012-05-16  9:41 [PATCH 0/5] Change old mail addresses to current ones Oskar Schirmer
  2012-05-16  9:41 ` [PATCH 1/5] xtensa: Change mail addresses of Hannes Weiner and Oskar Oskar Schirmer
  2012-05-16  9:41 ` [PATCH 2/5] i2c: Change mail address of Oskar Schirmer Oskar Schirmer
@ 2012-05-16  9:41 ` Oskar Schirmer
  2012-05-17 13:18   ` Jiri Kosina
  2012-05-16  9:41 ` [PATCH 4/5] lib: " Oskar Schirmer
  2012-05-16  9:41 ` [PATCH 5/5] arm/m68k: Change mail address of Se Oskar Schirmer
  4 siblings, 1 reply; 13+ messages in thread
From: Oskar Schirmer @ 2012-05-16  9:41 UTC (permalink / raw)
  To: linux-kernel; +Cc: trivial, hannes, shess, Oskar Schirmer, netdev

That old mail address doesnt exist any more.
This changes all occurences to my new address.

Signed-off-by: Oskar Schirmer <oskar@scara.com>
Cc: netdev@vger.kernel.org
---
 drivers/net/ethernet/s6gmac.c |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)

diff --git a/drivers/net/ethernet/s6gmac.c b/drivers/net/ethernet/s6gmac.c
index 1895605..6f0d284 100644
--- a/drivers/net/ethernet/s6gmac.c
+++ b/drivers/net/ethernet/s6gmac.c
@@ -1,7 +1,7 @@
 /*
  * Ethernet driver for S6105 on chip network device
  * (c)2008 emlix GmbH http://www.emlix.com
  * Authors:	Oskar Schirmer <os@emlix.com>
  *		Daniel Gloeckner <dg@emlix.com>
  *
  * This program is free software; you can redistribute it and/or
@@ -1070,4 +1070,4 @@ module_exit(s6gmac_exit);
 
 MODULE_LICENSE("GPL");
 MODULE_DESCRIPTION("S6105 on chip Ethernet driver");
-MODULE_AUTHOR("Oskar Schirmer <os@emlix.com>");
+MODULE_AUTHOR("Oskar Schirmer <oskar@scara.com>");
@@ -1,7 +1,7 @@
  * Ethernet driver for S6105 on chip network device
  * (c)2008 emlix GmbH http://www.emlix.com
- * Authors:	Oskar Schirmer <os@emlix.com>
+ * Authors:	Oskar Schirmer <oskar@scara.com>
  *		Daniel Gloeckner <dg@emlix.com>
  *
-- 
1.7.5.4


^ permalink raw reply related	[flat|nested] 13+ messages in thread

* Re: [PATCH 1/5] xtensa: Change mail addresses of Hannes Weiner and Oskar
  2012-05-16  9:41 ` [PATCH 1/5] xtensa: Change mail addresses of Hannes Weiner and Oskar Oskar Schirmer
@ 2012-05-17 13:15   ` Jiri Kosina
  2012-05-17 19:56     ` Johannes Weiner
  0 siblings, 1 reply; 13+ messages in thread
From: Jiri Kosina @ 2012-05-17 13:15 UTC (permalink / raw)
  To: Oskar Schirmer; +Cc: linux-kernel, hannes, shess, Chris Zankel

On Wed, 16 May 2012, Oskar Schirmer wrote:

> These old mail addresses dont exist any more.
> This changes all occurences to the authors' current addresses.
> 
> Signed-off-by: Oskar Schirmer <oskar@scara.com>
> Cc: Hannes Weiner <hannes@cmpxchg.org>

I'd like to get Acked-by from Johannes for this patch before applying.

Thanks.

> Cc: Chris Zankel <chris@zankel.net>
> ---
>  arch/xtensa/variants/s6000/dmac.c                 |    2 +-
>  arch/xtensa/variants/s6000/gpio.c                 |    4 ++--
>  arch/xtensa/variants/s6000/include/variant/dmac.h |    2 +-
>  arch/xtensa/variants/s6000/irq.c                  |    4 ++--
>  4 files changed, 6 insertions(+), 6 deletions(-)
> 
> diff --git a/arch/xtensa/variants/s6000/dmac.c b/arch/xtensa/variants/s6000/dmac.c
> index dc7f7c5..340f5bb 100644
> --- a/arch/xtensa/variants/s6000/dmac.c
> +++ b/arch/xtensa/variants/s6000/dmac.c
> @@ -1,5 +1,5 @@
>  /*
> - * Authors:	Oskar Schirmer <os@emlix.com>
> + * Authors:	Oskar Schirmer <oskar@scara.com>
>   *		Daniel Gloeckner <dg@emlix.com>
>   * (c) 2008 emlix GmbH http://www.emlix.com
>   *
> diff --git a/arch/xtensa/variants/s6000/gpio.c b/arch/xtensa/variants/s6000/gpio.c
> index 7af0757..b89541b 100644
> --- a/arch/xtensa/variants/s6000/gpio.c
> +++ b/arch/xtensa/variants/s6000/gpio.c
> @@ -2,8 +2,8 @@
>   * s6000 gpio driver
>   *
>   * Copyright (c) 2009 emlix GmbH
> - * Authors:	Oskar Schirmer <os@emlix.com>
> - *		Johannes Weiner <jw@emlix.com>
> + * Authors:	Oskar Schirmer <oskar@scara.com>
> + *		Johannes Weiner <hannes@cmpxchg.org>
>   *		Daniel Gloeckner <dg@emlix.com>
>   */
>  #include <linux/bitops.h>
> diff --git a/arch/xtensa/variants/s6000/include/variant/dmac.h b/arch/xtensa/variants/s6000/include/variant/dmac.h
> index e81735b..3f88d9f 100644
> --- a/arch/xtensa/variants/s6000/include/variant/dmac.h
> +++ b/arch/xtensa/variants/s6000/include/variant/dmac.h
> @@ -8,7 +8,7 @@
>   * Copyright (C) 2006 Tensilica Inc.
>   * Copyright (C) 2008 Emlix GmbH <info@emlix.com>
>   * Authors:	Fabian Godehardt <fg@emlix.com>
> - *		Oskar Schirmer <os@emlix.com>
> + *		Oskar Schirmer <oskar@scara.com>
>   *		Daniel Gloeckner <dg@emlix.com>
>   */
>  
> diff --git a/arch/xtensa/variants/s6000/irq.c b/arch/xtensa/variants/s6000/irq.c
> index 6651e32..81a241e 100644
> --- a/arch/xtensa/variants/s6000/irq.c
> +++ b/arch/xtensa/variants/s6000/irq.c
> @@ -2,8 +2,8 @@
>   * s6000 irq crossbar
>   *
>   * Copyright (c) 2009 emlix GmbH
> - * Authors:	Johannes Weiner <jw@emlix.com>
> - *		Oskar Schirmer <os@emlix.com>
> + * Authors:	Johannes Weiner <hannes@cmpxchg.org>
> + *		Oskar Schirmer <oskar@scara.com>
>   */
>  #include <linux/io.h>
>  #include <asm/irq.h>
> -- 
> 1.7.5.4
> 

-- 
Jiri Kosina
SUSE Labs

^ permalink raw reply	[flat|nested] 13+ messages in thread

* Re: [PATCH 5/5] arm/m68k: Change mail address of Se
  2012-05-16  9:41 ` [PATCH 5/5] arm/m68k: Change mail address of Se Oskar Schirmer
@ 2012-05-17 13:17   ` Jiri Kosina
  0 siblings, 0 replies; 13+ messages in thread
From: Jiri Kosina @ 2012-05-17 13:17 UTC (permalink / raw)
  To: Oskar Schirmer; +Cc: linux-kernel, hannes, shess, Geert Uytterhoeven

On Wed, 16 May 2012, Oskar Schirmer wrote:

> That old mail address doesnt exist any more.
> This changes all occurences to a current address.

I have fixed the subject and applied.

> 
> Signed-off-by: Oskar Schirmer <oskar@scara.com>
> Acked-by: Sebastian Heß <shess@hessware.de>
> Cc: Geert Uytterhoeven <geert@linux-m68k.org>
> ---
>  arch/m68k/platform/532x/config.c |    2 +-
>  1 files changed, 1 insertions(+), 1 deletions(-)
> 
> diff --git a/arch/m68k/platform/532x/config.c b/arch/m68k/platform/532x/config.c
> index 37082d0..21d6cb1 100644
> --- a/arch/m68k/platform/532x/config.c
> +++ b/arch/m68k/platform/532x/config.c
> @@ -7,7 +7,7 @@
>   *	Copyright (C) 2000, Lineo (www.lineo.com)
>   *	Yaroslav Vinogradov yaroslav.vinogradov@freescale.com
>   *	Copyright Freescale Semiconductor, Inc 2006
> - *	Copyright (c) 2006, emlix, Sebastian Hess <sh@emlix.com>
> + *	Copyright (c) 2006, emlix, Sebastian Hess <shess@hessware.de>
>   *
>   * This program is free software; you can redistribute it and/or modify
>   * it under the terms of the GNU General Public License as published by
> -- 
> 1.7.5.4
> 

-- 
Jiri Kosina
SUSE Labs

^ permalink raw reply	[flat|nested] 13+ messages in thread

* Re: [PATCH 3/5] net: Change mail address of Oskar Schirmer
  2012-05-16  9:41 ` [PATCH 3/5] net: " Oskar Schirmer
@ 2012-05-17 13:18   ` Jiri Kosina
  0 siblings, 0 replies; 13+ messages in thread
From: Jiri Kosina @ 2012-05-17 13:18 UTC (permalink / raw)
  To: Oskar Schirmer; +Cc: linux-kernel, hannes, shess, netdev

On Wed, 16 May 2012, Oskar Schirmer wrote:

> That old mail address doesnt exist any more.
> This changes all occurences to my new address.
> 
> Signed-off-by: Oskar Schirmer <oskar@scara.com>
> Cc: netdev@vger.kernel.org
> ---
>  drivers/net/ethernet/s6gmac.c |    4 ++--
>  1 files changed, 2 insertions(+), 2 deletions(-)
> 
> diff --git a/drivers/net/ethernet/s6gmac.c b/drivers/net/ethernet/s6gmac.c
> index 1895605..6f0d284 100644
> --- a/drivers/net/ethernet/s6gmac.c
> +++ b/drivers/net/ethernet/s6gmac.c
> @@ -1,7 +1,7 @@
>  /*
>   * Ethernet driver for S6105 on chip network device
>   * (c)2008 emlix GmbH http://www.emlix.com
> - * Authors:	Oskar Schirmer <os@emlix.com>
> + * Authors:	Oskar Schirmer <oskar@scara.com>
>   *		Daniel Gloeckner <dg@emlix.com>
>   *
>   * This program is free software; you can redistribute it and/or
> @@ -1070,4 +1070,4 @@ module_exit(s6gmac_exit);
>  
>  MODULE_LICENSE("GPL");
>  MODULE_DESCRIPTION("S6105 on chip Ethernet driver");
> -MODULE_AUTHOR("Oskar Schirmer <os@emlix.com>");
> +MODULE_AUTHOR("Oskar Schirmer <oskar@scara.com>");

I am applying this to trivial.git.

-- 
Jiri Kosina
SUSE Labs

^ permalink raw reply	[flat|nested] 13+ messages in thread

* Re: [PATCH 4/5] lib: Change mail address of Oskar Schirmer
  2012-05-16  9:41 ` [PATCH 4/5] lib: " Oskar Schirmer
@ 2012-05-17 13:18   ` Jiri Kosina
  0 siblings, 0 replies; 13+ messages in thread
From: Jiri Kosina @ 2012-05-17 13:18 UTC (permalink / raw)
  To: Oskar Schirmer; +Cc: linux-kernel, hannes, shess, Paul Gortmaker

On Wed, 16 May 2012, Oskar Schirmer wrote:

> That old mail address doesnt exist any more.
> This changes all occurences to my new address.
> 
> Signed-off-by: Oskar Schirmer <oskar@scara.com>
> Cc: Paul Gortmaker <paul.gortmaker@windriver.com>
> ---
>  include/linux/rational.h |    2 +-
>  lib/rational.c           |    2 +-
>  2 files changed, 2 insertions(+), 2 deletions(-)
> 
> diff --git a/include/linux/rational.h b/include/linux/rational.h
> index 4f532fc..bfa6a2b 100644
> --- a/include/linux/rational.h
> +++ b/include/linux/rational.h
> @@ -1,7 +1,7 @@
>  /*
>   * rational fractions
>   *
> - * Copyright (C) 2009 emlix GmbH, Oskar Schirmer <os@emlix.com>
> + * Copyright (C) 2009 emlix GmbH, Oskar Schirmer <oskar@scara.com>
>   *
>   * helper functions when coping with rational numbers,
>   * e.g. when calculating optimum numerator/denominator pairs for
> diff --git a/lib/rational.c b/lib/rational.c
> index d326da3..f0aa21c 100644
> --- a/lib/rational.c
> +++ b/lib/rational.c
> @@ -1,7 +1,7 @@
>  /*
>   * rational fractions
>   *
> - * Copyright (C) 2009 emlix GmbH, Oskar Schirmer <os@emlix.com>
> + * Copyright (C) 2009 emlix GmbH, Oskar Schirmer <oskar@scara.com>
>   *
>   * helper functions when coping with rational numbers
>   */

Applied.

-- 
Jiri Kosina
SUSE Labs

^ permalink raw reply	[flat|nested] 13+ messages in thread

* Re: [PATCH 1/5] xtensa: Change mail addresses of Hannes Weiner and Oskar
  2012-05-17 13:15   ` Jiri Kosina
@ 2012-05-17 19:56     ` Johannes Weiner
  0 siblings, 0 replies; 13+ messages in thread
From: Johannes Weiner @ 2012-05-17 19:56 UTC (permalink / raw)
  To: Jiri Kosina; +Cc: Oskar Schirmer, linux-kernel, shess, Chris Zankel

On Thu, May 17, 2012 at 03:15:21PM +0200, Jiri Kosina wrote:
> On Wed, 16 May 2012, Oskar Schirmer wrote:
> 
> > These old mail addresses dont exist any more.
> > This changes all occurences to the authors' current addresses.
> > 
> > Signed-off-by: Oskar Schirmer <oskar@scara.com>
> > Cc: Hannes Weiner <hannes@cmpxchg.org>
> 
> I'd like to get Acked-by from Johannes for this patch before applying.

Acked-by: Johannes Weiner <hannes@cmpxchg.org>

Thanks for the patch, Oskar.  And thanks for the quick response, Jiri!

^ permalink raw reply	[flat|nested] 13+ messages in thread

* Re: [PATCH 2/5] i2c: Change mail address of Oskar Schirmer
  2012-05-16  9:41 ` [PATCH 2/5] i2c: Change mail address of Oskar Schirmer Oskar Schirmer
@ 2012-05-24  9:18   ` Sonic Zhang
  2012-05-24  9:22     ` Jiri Kosina
  0 siblings, 1 reply; 13+ messages in thread
From: Sonic Zhang @ 2012-05-24  9:18 UTC (permalink / raw)
  To: Oskar Schirmer; +Cc: linux-kernel, trivial, hannes, shess, Jean Delvare

PING

On Wed, May 16, 2012 at 5:41 PM, Oskar Schirmer <oskar@scara.com> wrote:
> That old mail address doesnt exist any more.
> This changes all occurences to my new address.
>
> Signed-off-by: Oskar Schirmer <oskar@scara.com>
> Cc: Jean Delvare <khali@linux-fr.org>
> ---
>  drivers/i2c/busses/i2c-s6000.c |    2 +-
>  drivers/i2c/busses/i2c-s6000.h |    2 +-
>  2 files changed, 2 insertions(+), 2 deletions(-)
>
> diff --git a/drivers/i2c/busses/i2c-s6000.c b/drivers/i2c/busses/i2c-s6000.c
> index c64ba73..b76a29d 100644
> --- a/drivers/i2c/busses/i2c-s6000.c
> +++ b/drivers/i2c/busses/i2c-s6000.c
> @@ -3,7 +3,7 @@
>  *
>  * Description: Driver for S6000 Family I2C Interface
>  * Copyright (c) 2008 emlix GmbH
> - * Author:     Oskar Schirmer <os@emlix.com>
> + * Author:     Oskar Schirmer <oskar@scara.com>
>  *
>  * Partially based on i2c-bfin-twi.c driver by <sonic.zhang@analog.com>
>  * Copyright (c) 2005-2007 Analog Devices, Inc.
> diff --git a/drivers/i2c/busses/i2c-s6000.h b/drivers/i2c/busses/i2c-s6000.h
> index ff23b81..4936f9f 100644
> --- a/drivers/i2c/busses/i2c-s6000.h
> +++ b/drivers/i2c/busses/i2c-s6000.h
> @@ -6,7 +6,7 @@
>  * for more details.
>  *
>  * Copyright (C) 2008 Emlix GmbH <info@emlix.com>
> - * Author:     Oskar Schirmer <os@emlix.com>
> + * Author:     Oskar Schirmer <oskar@scara.com>
>  */
>
>  #ifndef __DRIVERS_I2C_BUSSES_I2C_S6000_H
> --
> 1.7.5.4
>
> --
> To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
> the body of a message to majordomo@vger.kernel.org
> More majordomo info at  http://vger.kernel.org/majordomo-info.html
> Please read the FAQ at  http://www.tux.org/lkml/

^ permalink raw reply	[flat|nested] 13+ messages in thread

* Re: [PATCH 2/5] i2c: Change mail address of Oskar Schirmer
  2012-05-24  9:18   ` Sonic Zhang
@ 2012-05-24  9:22     ` Jiri Kosina
  0 siblings, 0 replies; 13+ messages in thread
From: Jiri Kosina @ 2012-05-24  9:22 UTC (permalink / raw)
  To: Sonic Zhang; +Cc: Oskar Schirmer, linux-kernel, hannes, shess, Jean Delvare

On Thu, 24 May 2012, Sonic Zhang wrote:

> PING

What is this ping about? It's already in Linus' tree, commit 8533848809c.

> On Wed, May 16, 2012 at 5:41 PM, Oskar Schirmer <oskar@scara.com> wrote:
> > That old mail address doesnt exist any more.
> > This changes all occurences to my new address.
> >
> > Signed-off-by: Oskar Schirmer <oskar@scara.com>
> > Cc: Jean Delvare <khali@linux-fr.org>
> > ---
> >  drivers/i2c/busses/i2c-s6000.c |    2 +-
> >  drivers/i2c/busses/i2c-s6000.h |    2 +-
> >  2 files changed, 2 insertions(+), 2 deletions(-)
> >
> > diff --git a/drivers/i2c/busses/i2c-s6000.c b/drivers/i2c/busses/i2c-s6000.c
> > index c64ba73..b76a29d 100644
> > --- a/drivers/i2c/busses/i2c-s6000.c
> > +++ b/drivers/i2c/busses/i2c-s6000.c
> > @@ -3,7 +3,7 @@
> >  *
> >  * Description: Driver for S6000 Family I2C Interface
> >  * Copyright (c) 2008 emlix GmbH
> > - * Author:     Oskar Schirmer <os@emlix.com>
> > + * Author:     Oskar Schirmer <oskar@scara.com>
> >  *
> >  * Partially based on i2c-bfin-twi.c driver by <sonic.zhang@analog.com>
> >  * Copyright (c) 2005-2007 Analog Devices, Inc.
> > diff --git a/drivers/i2c/busses/i2c-s6000.h b/drivers/i2c/busses/i2c-s6000.h
> > index ff23b81..4936f9f 100644
> > --- a/drivers/i2c/busses/i2c-s6000.h
> > +++ b/drivers/i2c/busses/i2c-s6000.h
> > @@ -6,7 +6,7 @@
> >  * for more details.
> >  *
> >  * Copyright (C) 2008 Emlix GmbH <info@emlix.com>
> > - * Author:     Oskar Schirmer <os@emlix.com>
> > + * Author:     Oskar Schirmer <oskar@scara.com>
> >  */
> >
> >  #ifndef __DRIVERS_I2C_BUSSES_I2C_S6000_H

-- 
Jiri Kosina
SUSE Labs

^ permalink raw reply	[flat|nested] 13+ messages in thread

end of thread, other threads:[~2012-05-24  9:22 UTC | newest]

Thread overview: 13+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2012-05-16  9:41 [PATCH 0/5] Change old mail addresses to current ones Oskar Schirmer
2012-05-16  9:41 ` [PATCH 1/5] xtensa: Change mail addresses of Hannes Weiner and Oskar Oskar Schirmer
2012-05-17 13:15   ` Jiri Kosina
2012-05-17 19:56     ` Johannes Weiner
2012-05-16  9:41 ` [PATCH 2/5] i2c: Change mail address of Oskar Schirmer Oskar Schirmer
2012-05-24  9:18   ` Sonic Zhang
2012-05-24  9:22     ` Jiri Kosina
2012-05-16  9:41 ` [PATCH 3/5] net: " Oskar Schirmer
2012-05-17 13:18   ` Jiri Kosina
2012-05-16  9:41 ` [PATCH 4/5] lib: " Oskar Schirmer
2012-05-17 13:18   ` Jiri Kosina
2012-05-16  9:41 ` [PATCH 5/5] arm/m68k: Change mail address of Se Oskar Schirmer
2012-05-17 13:17   ` Jiri Kosina

This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.